@@ -125,11 +125,11 @@ def wrap(lambda_handler):
         try:
             trace_id = event['headers']['X-Amzn-Trace-Id']
         except (TypeError, KeyError):
-            trace_id = event['trace_id']
+            trace_id = os.getenv('_X_AMZN_TRACE_ID')
 
         setup(
-            level=os.getenv('log_level', 'DEBUG'),
-            boto_level=os.getenv('boto_level', 'WARN'),
+            level=os.getenv('LOG_LEVEL', 'DEBUG'),
+            boto_level=os.getenv('BOTO_LEVEL', 'WARN'),
             request_id=request_id,
             trace_id=trace_id,
             function_name=context.function_name,
